All Modules
```````````

.. toctree:: :maxdepth: 1

  zhmc_hba - Manages HBAs in existing partitions <zhmc_hba_module>
  zhmc_nic - Manages NICs in existing partitions <zhmc_nic_module>
  zhmc_partition - Manages partitions <zhmc_partition_module>
  zhmc_virtual_function - Manages virtual functions in existing partitions <zhmc_virtual_function_module>



.. note::
    -  (D): This marks a module as deprecated, which means a module is kept for backwards compatibility but usage is discouraged.
       The module documentation details page may explain more about this rationale.
